Page 67 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 67

Home

    Henry Grady Weaver in his book, The Mainspring of
    Human Progress, explained how this brought down the
    Roman Empire:

    The hairsplitting economic regulations were
    perfected by Diocletian, whose stern directives were so
    efficiently administered that farmers could no longer
    farm; and many of the small businessmen, faced with
    starvation, committed suicide in preference to being
    executed for black marketing.

    When there was no work, the beneficent government
    then began to tax the rich to provide the populace with
    bread and entertainment. Eventually, so many workers
    were forced into tax-supported relief that there was not

    enough production to pay the tax bills. The result; the
    Roman Empire collapsed into the dark ages.

    In England, to solve the problem of over production
    of wool, Charles II decreed that no corpse could be
    buried that was not wrapped in a woolen shroud. The
    wool was buried, but ghouls dug up the corpses, stole the
    shrouds and sold them on the black market. Before

    Adam Smith's Wealth of Nations was published (in
    1776), and his ideas made the Industrial Revolution
    possible, England was known as an island surrounded by

    smugglers.
    Weaver also quoted Buckle's comments on France:

    Tn every quarter, and at every moment, the hand of
    government was felt. Duties on importation, and duties

    62

    The Secret Side of History